( cd usr/share/texmf/bin ; rm -rf allec )
( cd usr/share/texmf/bin ; ln -sf allcm allec )
( cd usr/share/texmf/bin ; rm -rf dvilj6 )
( cd usr/share/texmf/bin ; ln -sf dvilj4 dvilj6 )
( cd usr/share/texmf/bin ; rm -rf einitex )
( cd usr/share/texmf/bin ; ln -sf etex einitex )
( cd usr/share/texmf/bin ; rm -rf elatex )
( cd usr/share/texmf/bin ; ln -sf etex elatex )
( cd usr/share/texmf/bin ; rm -rf evirtex )
( cd usr/share/texmf/bin ; ln -sf etex evirtex )
( cd usr/share/texmf/bin ; rm -rf inimf )
( cd usr/share/texmf/bin ; ln -sf mf inimf )
( cd usr/share/texmf/bin ; rm -rf inimpost )
( cd usr/share/texmf/bin ; ln -sf mpost inimpost )
( cd usr/share/texmf/bin ; rm -rf iniomega )
( cd usr/share/texmf/bin ; ln -sf omega iniomega )
( cd usr/share/texmf/bin ; rm -rf initex )
( cd usr/share/texmf/bin ; ln -sf tex initex )
( cd usr/share/texmf/bin ; rm -rf kpsepath )
( cd usr/share/texmf/bin ; ln -sf kpsetool kpsepath )
( cd usr/share/texmf/bin ; rm -rf kpsexpand )
( cd usr/share/texmf/bin ; ln -sf kpsetool kpsexpand )
( cd usr/share/texmf/bin ; rm -rf lambda )
( cd usr/share/texmf/bin ; ln -sf omega lambda )
( cd usr/share/texmf/bin ; rm -rf latex )
( cd usr/share/texmf/bin ; ln -sf tex latex )
( cd usr/share/texmf/bin ; rm -rf pdfeinitex )
( cd usr/share/texmf/bin ; ln -sf pdfetex pdfeinitex )
( cd usr/share/texmf/bin ; rm -rf pdfelatex )
( cd usr/share/texmf/bin ; ln -sf pdfetex pdfelatex )
( cd usr/share/texmf/bin ; rm -rf pdfevirtex )
( cd usr/share/texmf/bin ; ln -sf pdfetex pdfevirtex )
( cd usr/share/texmf/bin ; rm -rf pdfinitex )
( cd usr/share/texmf/bin ; ln -sf pdftex pdfinitex )
( cd usr/share/texmf/bin ; rm -rf pdflatex )
( cd usr/share/texmf/bin ; ln -sf pdftex pdflatex )
( cd usr/share/texmf/bin ; rm -rf pdfvirtex )
( cd usr/share/texmf/bin ; ln -sf pdftex pdfvirtex )
( cd usr/share/texmf/bin ; rm -rf texhash )
( cd usr/share/texmf/bin ; ln -sf mktexlsr texhash )
( cd usr/share/texmf/bin ; rm -rf virmf )
( cd usr/share/texmf/bin ; ln -sf mf virmf )
( cd usr/share/texmf/bin ; rm -rf virmpost )
( cd usr/share/texmf/bin ; ln -sf mpost virmpost )
( cd usr/share/texmf/bin ; rm -rf viromega )
( cd usr/share/texmf/bin ; ln -sf omega viromega )
( cd usr/share/texmf/bin ; rm -rf virtex )
( cd usr/share/texmf/bin ; ln -sf tex virtex )
